* [PATCH] ACPICA: allow Load(OEMx) tables
@ 2007-05-24 5:16 Len Brown
2007-05-24 6:25 ` [PATCH] ACPICA: allow Load(OEMx) tables - take 2 Len Brown
0 siblings, 1 reply; 2+ messages in thread
From: Len Brown @ 2007-05-24 5:16 UTC (permalink / raw)
To: linux-acpi
HP and Hitachi machines have been implemented with SSDTs
that use the "OEMx" signatures. But upon Load, ACPICA is rejecting
these tables because they are not using the "SSDT" signature.
ACPI Error (tbinstal-0134): Table has invalid signature [OEMx], must be SSDT...
Signed-off-by: Len Brown <len.brown@intel.com>
diff --git a/drivers/acpi/tables/tbinstal.c b/drivers/acpi/tables/tbinstal.c
index 0e7b121..609f67e 100644
--- a/drivers/acpi/tables/tbinstal.c
+++ b/drivers/acpi/tables/tbinstal.c
@@ -123,14 +123,14 @@ acpi_tb_add_table(struct acpi_table_desc *table_desc,
}
}
/* The table must be either an SSDT or a PSDT */
if ((!ACPI_COMPARE_NAME(table_desc->pointer->signature, ACPI_SIG_PSDT))
&&
- (!ACPI_COMPARE_NAME(table_desc->pointer->signature, ACPI_SIG_SSDT)))
- {
+ (!ACPI_COMPARE_NAME(table_desc->pointer->signature, ACPI_SIG_SSDT))
+ && (!strncmp(table_desc->pointer->signature, "OEM", 3))) {
ACPI_ERROR((AE_INFO,
- "Table has invalid signature [%4.4s], must be SSDT or PSDT",
+ "Table has invalid signature [%4.4s], must be SSDT, PSDT or OEMx",
table_desc->pointer->signature));
return_ACPI_STATUS(AE_BAD_SIGNATURE);
}
^ permalink raw reply related [flat|nested] 2+ messages in thread
* [PATCH] ACPICA: allow Load(OEMx) tables - take 2
2007-05-24 5:16 [PATCH] ACPICA: allow Load(OEMx) tables Len Brown
@ 2007-05-24 6:25 ` Len Brown
0 siblings, 0 replies; 2+ messages in thread
From: Len Brown @ 2007-05-24 6:25 UTC (permalink / raw)
To: linux-acpi, Pallipadi, Venkatesh
Subject: ACPICA: allow Load(OEMx) tables
From: Len Brown <len.brown@intel.com>
HP and Hitachi machines have been implemented with SSDT's
that use the "OEMx" signatures. But upon Load, ACPICA is rejecting
these tables because they are not using the "SSDT" signature.
ACPI Error (tbinstal-0134): Table has invalid signature [OEMx], must be SSDT...
Signed-off-by: Len Brown <len.brown@intel.com>
---
tbinstal.c | 8 ++++----
1 file changed, 4 insertions(+), 4 deletions(-)
@@ -123,14 +123,14 @@ acpi_tb_add_table(struct acpi_table_desc *table_desc,
}
}
- /* The table must be either an SSDT or a PSDT */
+ /* The table must be either an SSDT or a PSDT or an OEMx */
if ((!ACPI_COMPARE_NAME(table_desc->pointer->signature, ACPI_SIG_PSDT))
&&
diff --git a/drivers/acpi/tables/tbinstal.c b/drivers/acpi/tables/tbinstal.c
index 0e7b121..3bc0c67 100644
--- a/drivers/acpi/tables/tbinstal.c
+++ b/drivers/acpi/tables/tbinstal.c
@@ -123,14 +123,14 @@ acpi_tb_add_table(struct acpi_table_desc *table_desc,
}
}
/* The table must be either an SSDT or a PSDT */
if ((!ACPI_COMPARE_NAME(table_desc->pointer->signature, ACPI_SIG_PSDT))
&&
- (!ACPI_COMPARE_NAME(table_desc->pointer->signature, ACPI_SIG_SSDT)))
- {
+ (!ACPI_COMPARE_NAME(table_desc->pointer->signature, ACPI_SIG_SSDT))
+ && (strncmp(table_desc->pointer->signature, "OEM", 3))) {
ACPI_ERROR((AE_INFO,
- "Table has invalid signature [%4.4s], must be SSDT or PSDT",
+ "Table has invalid signature [%4.4s], must be SSDT, PSDT or OEMx",
table_desc->pointer->signature));
return_ACPI_STATUS(AE_BAD_SIGNATURE);
}
^ permalink raw reply related [flat|nested] 2+ messages in thread
end of thread, other threads:[~2007-05-24 6:26 UTC | newest]
Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2007-05-24 5:16 [PATCH] ACPICA: allow Load(OEMx) tables Len Brown
2007-05-24 6:25 ` [PATCH] ACPICA: allow Load(OEMx) tables - take 2 Len Brown
This is an external index of several public inboxes,
@@ -123,14 +123,14 @@ acpi_tb_add_table(struct acpi_table_desc *table_desc,
}
}
- /* The table must be either an SSDT or a PSDT */
+ /* The table must be either an SSDT or a PSDT or an OEMx */
if ((!ACPI_COMPARE_NAME(table_desc->pointer->signature, ACPI_SIG_PSDT))
&&
see mirroring instructions on how to clone and mirror
all data and code used by this external index.